@@ -1,6 +1,7 @@
 import datetime
 import json
 import re
+from math import ceil
 
 import caldav
 from django.db import models
@@ -20,6 +21,8 @@ class Settings(models.Model):
     calendar_lookahead = models.PositiveIntegerField(default=3)
     beach_mode = models.BooleanField(default=False)
     trash_period = models.PositiveIntegerField(default=30)
+    mood_log_hours = models.PositiveIntegerField(default=19, validators=[MinValueValidator(0), MaxValueValidator(23)])
+    mood_activities = models.TextField(default="Hiking 🥾\nRunning 🏃\nParty 🎉")
 
     class Meta:
 
@@ -28,6 +31,14 @@ class Settings(models.Model):
     def __str__(self):
         return f"Settings(user={self.user})"
 
+    @property
+    def mood_activities_list(self) -> list[tuple[str, str]]:
+        activities = []
+        for line in self.mood_activities.strip().split("\n"):
+            label, emoji = line.strip().split(" ")
+            activities.append((label, emoji))
+        return activities
+
 
 class Category(models.Model):
     """Represent a general category"""
@@ -122,9 +133,13 @@ class Note(Document):
 
     def get_absolute_url(self):
         return reverse("orgapy:note", kwargs={"object_id": self.id})
-    
+
     def ongoing_projects(self):
         return self.project_set.exclude(status=Project.ARCHIVED) # type: ignore
+    
+    @property
+    def archived_projects_count(self) -> int:
+        return self.project_set.filter(status=Project.ARCHIVED).count() # type: ignore
 
 
 class SheetGroup(models.Model):
@@ -279,10 +294,12 @@ class Project(models.Model):
     ACTIVE = "AC"
     INACTIVE = "IN"
     ARCHIVED = "AR"
+    FUTURE = "FU"
     STATUS_CHOICES = [
         (ACTIVE, "Active"),
         (INACTIVE, "Inactive"),
         (ARCHIVED, "Archived"),
+        (FUTURE, "Future"),
     ]
 
     id = models.BigAutoField(primary_key=True)
@@ -311,13 +328,13 @@ class Project(models.Model):
 
     def get_absolute_url(self):
         return reverse("orgapy:project", kwargs={"object_id": self.id})
-    
+
     @property
     def items_count(self) -> int:
         if self.checklist is None:
             return 0
         return len(re.findall(r"^\[[ x]\]", self.checklist, re.MULTILINE))
-    
+
     @property
     def completed_items_count(self) -> int:
         if self.checklist is None:
@@ -337,7 +354,7 @@ class Project(models.Model):
         if self.note is not None and self.title is not None:
             return f"{self.note.title} - {self.title}"
         return "Untitled"
-    
+
     def to_json_dict(self) -> dict:
         return {
             "id": self.id,
@@ -352,6 +369,14 @@ class Project(models.Model):
             },
             "status": self.status,
         }
+    
+    @property
+    def progress(self) -> int:
+        q = self.items_count
+        if q == 0:
+            return 0
+        p = self.completed_items_count
+        return ceil(100 * p / q)
 
 
 class Calendar(models.Model):
@@ -563,7 +588,7 @@ class ProgressLog(models.Model):
 
 
 class PushSubscription(models.Model):
-    
+
     id = models.BigAutoField(primary_key=True)
     user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE)
     subscription = models.TextField()
@@ -576,3 +601,58 @@ class PushSubscription(models.Model):
 
     def __str__(self):
         return f"PushSubscription(user={self.user}, name={self.name})"
+
+
+class MoodLog(models.Model):
+
+    UNSET = 0
+    BAD = 1
+    NEUTRAL = 2
+    GOOD = 3
+
+    id = models.BigAutoField(primary_key=True)
+    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE)
+    created_at = models.DateTimeField(auto_now_add=True)
+    date = models.DateField()
+    mood = models.PositiveIntegerField()
+    energy = models.PositiveIntegerField()
+    health = models.PositiveIntegerField()
+    stress = models.PositiveIntegerField()
+    activities = models.TextField(default="")
+
+    class Meta:
+
+        ordering = ["user", "created_at"]
+
+    def __str__(self):
+        return f"MoodLog(user={self.user}, date={self.date})"
+
+    @staticmethod
+    def tracker_classname(value) -> str:
+        if value == 1:
+            return "mood-bad"
+        elif value == 2:
+            return "mood-neutral"
+        elif value == 3:
+            return "mood-good"
+        return ""
+
+    @property
+    def mood_classname(self) -> str:
+        return self.tracker_classname(self.mood)
+
+    @property
+    def energy_classname(self) -> str:
+        return self.tracker_classname(self.energy)
+
+    @property
+    def health_classname(self) -> str:
+        return self.tracker_classname(self.health)
+
+    @property
+    def stress_classname(self) -> str:
+        return self.tracker_classname(self.stress)
+
+    @property
+    def activities_display(self) -> str:
+        return self.activities.replace(",", " ")
