@@ -116,11 +116,15 @@ class Project {
         const dialogHeader = create(dialog, "div", "dialog-header");
         const noteTitle = create(dialogHeader, "b");
         if (this.note != null) noteTitle.textContent = this.note.title;
-        const noteLink = create(dialogHeader, "a", "action-button");
+        const actionButtons = create(dialogHeader, "span", "action-buttons");
+        const noteLink = create(actionButtons, "a", "action-button");
         noteLink.innerHTML = `<i class="ri-arrow-right-circle-line"></i>`;
         if (this.note != null) noteLink.href = this.note.url;
-        const noteClear = create(dialogHeader, "span", "action-button");
-        noteClear.innerHTML = `<i class="ri-close-line"></i>`;
+        const noteEditLink = create(actionButtons, "a", "action-button");
+        noteEditLink.innerHTML = `<i class="ri-pencil-fill"></i>`;
+        if (this.note != null) noteEditLink.href = this.note.url + "/edit";
+        const noteClear = create(actionButtons, "span", "action-button");
+        noteClear.innerHTML = `<i class="ri-delete-bin-line"></i>`;
         const noteIframe = create(dialog, "iframe", "dialog-body");
         if (this.note != null) noteIframe.src = this.note.url + "/standalone";
         noteIframe.width = 400;
@@ -184,26 +188,10 @@ class Project {
 
     openStatusDialog() {
         var self = this;
-        const dialog = create(this.container, "dialog");
-        dialog.setAttribute("closedby", "any");
-        const dialogHeader = create(dialog, "div", "dialog-header");
-        create(dialogHeader, "b").textContent = this.reference();
-        const dialogBody = create(dialog, "div", "dialog-body");
-        const select = create(create(dialogBody, "p"), "select");
-        for (const [optionName, optionValue] of [["Active", "AC"], ["Inactive", "IN"], ["Archived", "AR"]]) {
-            const option = create(select, "option");
-            option.textContent = optionName;
-            option.value = optionValue;
-            if (self.status == optionValue) option.selected = true;
-        }
-        select.addEventListener("change", () => {
-            self.setStatus(select.options[select.selectedIndex].value);
-            dialog.close();
+        openProjectStatusDialog(this.container.querySelector(".project-status"), this.id, (newStatus, response) => {
+            self.status = newStatus;
+            self.modification = response.modification;
         });
-        const closeButton = create(create(dialogBody, "div", "row"), "button");
-        closeButton.textContent = "Close";
-        closeButton.addEventListener("click", () => {dialog.close();});
-        dialog.showModal();
     }
 
     inflateHeader() {
@@ -220,6 +208,25 @@ class Project {
         }
         header.className = "project-header";
 
+        const status = create(header, "span", "project-status label");
+        status.setAttribute("status", this.status);
+        if (this.status == "AC") {
+            status.textContent = "ACTIVE";
+        } else if (this.status == "IN") {
+            status.textContent = "INACTIVE";
+            status.classList.add("label-grey");
+        } else if (this.status == "AR") {
+            status.textContent = "ARCHIVED";
+            status.classList.add("label-purple");
+        } else if (this.status == "FU") {
+            status.textContent = "FUTURE";
+            status.classList.add("label-pink");
+        }
+        status.addEventListener("click", (e) => {
+            e.stopPropagation();
+            self.openStatusDialog();
+        });
+
         const badge = create(header, "span", "project-badge");
         let total = 0;
         let completed = 0;
@@ -231,6 +238,9 @@ class Project {
             badge.classList.add("empty");
         } else if (completed == total) {
             badge.classList.add("done");
+        } else {
+            const progress = Math.floor(100 * completed / total);
+            badge.style.background = `linear-gradient(90deg,rgba(37, 135, 50, 1)${progress}%,rgb(48, 48, 48) ${progress + 1}%)`
         }
         badge.innerHTML = `<i class="ri-checkbox-circle-line"></i> ${completed}/${total}`;
         badge.addEventListener("dblclick", (e) => {
@@ -420,6 +430,8 @@ class Project {
             this.container.classList.add("archived");
         } else if (this.status == "IN") {
             this.container.classList.add("inactive");
+        } else if (this.status == "FU") {
+            this.container.classList.add("future");
         }
         this.inflateHeader();
         this.inflateBody();
@@ -634,7 +646,7 @@ class TemporaryProject extends Project {
 
 const STORAGE_KEY_RANK = "orgapy.projects.ranks";
 
-function saveProjectRanks(container, container, ordering) {
+function saveProjectRanks(container, ordering) {
     let ranks = {};
     container.querySelectorAll(".project").forEach((project, i) => {
         let projectId = project.getAttribute("project_id");
@@ -707,4 +719,32 @@ function onButtonProjectCreate(container, note, forceExpand) {
     }, 1);
 }
 
+function openProjectStatusDialog(statusSpan, projectId, onSuccess=null) {
+    const dialog = create(document.body, "dialog", "dialog-card row");
+    dialog.setAttribute("closedby", "any");
+    const currentStatus = statusSpan.getAttribute("status");
+    for (const [value, name, labelClass] of [["AC", "ACTIVE", ""], ["IN", "INACTIVE", "label-grey"], ["AR", "ARCHIVED", "label-purple"], ["FU", "FUTURE", "label-pink"]]) {
+        if (value == currentStatus) continue;
+        const option = create(dialog, "span", "label " + labelClass);
+        option.textContent = name;
+        option.addEventListener("click", () => {
+            dialog.close();
+            apiPost("set-project-status", {project_id: projectId, status: value}, (response) => {
+                if (statusSpan != null) {
+                    statusSpan.setAttribute("status", value);
+                    statusSpan.textContent = name;
+                    statusSpan.className = "project-status label-inline label " + labelClass; 
+                }
+                if (onSuccess != null) {
+                    onSuccess(value, response);
+                }
+            });
+        });
+    }
+    dialog.addEventListener("close", () => {
+        document.body.removeChild(dialog);
+    });
+    dialog.showModal();
+}
+
 window.addEventListener("click", clearContextMenus);
\ No newline at end of file
